summaryrefslogtreecommitdiffstats
path: root/testing/xvfb.py
diff options
context:
space:
mode:
Diffstat (limited to 'testing/xvfb.py')
-rwxr-xr-xtesting/xvfb.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/testing/xvfb.py b/testing/xvfb.py
index 6ac0056..51c1ad3 100755
--- a/testing/xvfb.py
+++ b/testing/xvfb.py
@@ -82,7 +82,7 @@ def run_executable(cmd, build_dir, env):
"""Runs an executable within a xvfb buffer on linux or normally on other
platforms.
Requires that both xvfb and icewm are installed on linux.
Detects recursion with an environment variable and do not create a recursive X
buffer if present.
@@ -109,11 +109,11 @@ def run_executable(cmd, build_dir, env):
# Some ChromeOS tests need a window manager. Technically, it could be
# another script but that would be overkill.
try:
- ice_cmd = ['icewm']
+ wm_cmd = ['openbox']
subprocess.Popen(
- ice_cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env)
+ wm_cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env)
except OSError:
- print >> sys.stderr, 'Failed to run %s' % ' '.join(ice_cmd)
+ print >> sys.stderr, 'Failed to run %s' % ' '.join(wm_cmd)
return 1
return test_env.run_executable(cmd, env)
finally:
@@ -82,7 +82,7 @@ def run_executable(cmd, build_dir, env):
"""Runs an executable within a xvfb buffer on linux or normally on other
platforms.
- Requires that both xvfb and icewm are installed on linux.
+ Requires that both xvfb and openbox are installed on linux.
Detects recursion with an environment variable and do not create a recursive X
buffer if present.